@@ -19,5 +19,5 @@ def pie802_prefer_simple_any_all(node: ast.Call, errors: list[Error]) -> None:
 
 
 PIE802 = partial(
-    Error, message="PIE802: prefer-simple-any-all: remove unnecessary comprehension."
+    Error, message="PIE802 prefer-simple-any-all: remove unnecessary comprehension."
 )
